<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko_KR" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>브라우저 바깥에 생활이 존재 합니다!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>버전 %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>라이센스 소유자: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1는 무료 프로그램이지만 개발에는 시간과 노력이 소요 됩니다.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>%2의 계속된 개발을 위해  &lt;a href=&apos;%1&apos;&gt;기부&lt;/a&gt;룰 해주세요.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>%2을(를) 사용해서 %1를 사용자의 언어로 번역 하세요.</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>아이콘 디자인: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;하에 배포 됩니다.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>닫기(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>프로그램 정보</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>라이센스 정보 입력</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>Email(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>코드(&amp;C)</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>%1을(를) 구입 하세요</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>데모버전이 만료되었습니다!</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>구입 버전은 방해받지 않고 비디오를 감상 할수 있습니다.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>라이센스를 구입하지 않으면, %1일후 만료 됩니다.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>구입하면, 개발자가 %1를 만드는데 드는 소중한 노력을 지원 합니다.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>데모 사용</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>라이센스 입력</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>라이센스 구입</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>By %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>모든 비디오</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>시청하지 않은 비디오</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>마지막 업데이트</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>마지막 추가</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>마지막 시청</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>가장 많이 시청</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>정렬</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>모두 시청함으로 표시</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>업데이트 표시</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>구독 항목이 없습니다. 채널을 구독 하려면 별 아이콘을 사용 하세요.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>모든 비디오</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>시청하지 않은 비디오</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>모두 시청함으로 표시</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>구독 취소</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>현재 업데이트된 구독이 없습니다.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>지금</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 조회수</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>바이트</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>바이트/초</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/초</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/초</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>초</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>분</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 남음</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 downloaded in %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>다운로드 완료</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>위치 변경...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>다운로드 위치 선택</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>다운로드 위치 변경됨</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>현재 다운로드는 이전 위치에 저장 됩니다.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>다운로드 위치: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>실행 파일이 바이러스 또는 다른 외부 원인에 의해 손상되었습니다.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1을 실행할 수 없습니다. 다시 설치하시기 바랍니다.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>재설치</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>재생/일시정지</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>정지</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>현재 트랙 이후 정지</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>다음 트랙</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>이전 트랙</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>볼륨 키우기</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>볼륨 줄이기</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>음소거</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>되감기</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>빨리감기</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>키워드로 비디오 채널 검색</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>탐색</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>카테고리로 비디오 탐색</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>구독</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>채널 구독</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>편안하게 하세요.</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>에러</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>창 (&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>최소화 (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>정지(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>재생을 멈추고 검색 창로 이동</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>이전(&amp;R)</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>이전 트랙으로 이동</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>건너뛰기(&amp;K)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>다음 비디오로 건너뛰기</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>재생(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>재생 이어하기</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>전체 화면(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>전체화면 보기</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>컴팩트 모드(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>도구 모음과 재생 목록 숨기기</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>YouTube 페이지 열기(&amp;Y)</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>재생을 멈추고 YouTube 비디오페이지로 이동</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube 링크 복사(&amp;L)</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>현재 비디오의 YouTube링크를 클립보드에 복사</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>비디오 스트림 URL을 복사(&amp;U)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>현재 비디오 스트림 URL을 클립보드에 복사</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>비디오 부분 찾기(&amp;P)</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>연결된 다른 비디오 조각을 가능한한 올바른 순서로 찾기</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>제거(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>재생 목록에서 현재 비디오 제거</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>위로 이동(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>재생 목록에서 선택된 비디오의 위 항목으로 이동</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>아래로 이동(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>재생 목록에서 선택된 비디오의 아래 항목으로 이동</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>최근 검색 지우기(&amp;C)</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>검색했던 목록 지우기. 되돌릴수 없음.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>종료(&amp;Q)</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>안녕히 가세요.</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>웹사이트(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1의 웹사이트</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>기부하기(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1의 계속되는 개발을 도와 주세요.</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>프로그램 정보(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1의 정보</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>볼륨 소거</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>수동으로 재생 시작(&amp;M)</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>수동으로 비디오 재생 시작 하기</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>다운로드(&amp;D)</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>비디오 다운로드에 대한 자세한 정보 표시</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>다운로드(&amp;D)</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>현재 비디오 다운로드</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>스냅샷 찍기(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>채널 구독(&amp;S)</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>%1을(를) 사용해서 현재 비디오 공유</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>Email(&amp;E)</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>닫기(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>위에 떠있기(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>이 비디오 재생 후 정지(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>문제점 보고...(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>검색 재정의(&amp;R)...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>추가정보...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>관련된 비디오...(&amp;R)</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>현재 비디오와 관련된 비디오 보기</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>브라우저에서 열기(&amp;B)...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>제한된 보기</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>부적절한 내용을 포함한 동영상 숨기기</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>%1를 좋아하시나요? 평점을 주세요!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 구입...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>어플리케이션(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>재생(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>재생 목록(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>비디오(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>공유(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>보기(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1을(를) 눌러 볼륨 증가 , %2을(를) 눌러 볼륨 감소</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>콘텐츠 위치 선택</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 열기</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>다운로드가 진행 중인데 %1을(를) 종료 할까요?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>%1를 지금 종료하면, 다운로드는 취소 됩니다.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>다운로드 취소하고 종료</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>다운로드 끝날때 까지 대기</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>에러: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>일시정지(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>재생 일시정지</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>로딩중 (&amp;L)</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>전체 화면 나가기(&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>남은 시간: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>볼륨 %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>볼륨 음소거됨</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>볼륨 응소거 해제됨</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>최대 비디오 해상도가 %1(으)로 설정됨</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>이제 개인 정보가 안전 합니다.</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>다운로드 완료</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 version %2이(가) 사용 가능 합니다.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>다음에 알리기</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>업데이트</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>이제 YouTube 링크를 다른프로그램에 붙여 넣을수 있습니다.</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>이제 비디오 스트림 URL을 다른프로그램에 붙여 넣을수 있습니다.</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>해당 링크는 제한된 시간 동안만 유효 합니다.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1 다운로드</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>of</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>부분</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>에피소드</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>%1에서 전송됨</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>%1 구독 해제</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>%1 구독</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>%1 구독 해지됨</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>%1 구독됨</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1의 새 버전이 존재 합니다!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2이(가) 존재 합니다. 사용자의 사용 버전은 %3 입니다.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>지금 다운로드 할까요?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>이 버전 건너뛰기</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>다음에 알리기</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>업데이트 설치</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 of %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>준비</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>실패</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>끝남</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>중지됨</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>다운로드 중지</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>%1에서 보기</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>부모 폴더 열기</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>다운로드 재시작</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>%1 추가 보기</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>비디오없음</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>더 이상 비디오 없음</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>정렬</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>관련성</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>재생 횟수</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>점수</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>언제나</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>오늘</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7일</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30일</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>기간</translation>
    </message>
    <message>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>짧음</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>김</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>4분 이하</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4 ~ 20분 사이</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>20분 이상</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p 이상</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>마침</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>마침</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;에 오신걸 환영 합니다!</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>비디오 보기 시작</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>키워드</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>언터</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>최근 키워드</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>최근 채널</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>풀 버전 구입</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>뒤로(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>%1(으)로 이동</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>%1(으)로 이동</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>검색 재정의</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>원했던 단어: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>위치 변경...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>%1에 스냅샷 저장됨</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>스냅샷 위치 변경됨</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>가장 유명</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>업데이트 다운로드...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>%1 다운로드중</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>알제리아</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>아르헨티나</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>오스트레일리아</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>벨기에</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>브라질</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>캐나다</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>칠레</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>콜롬비아</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>체코</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>이집트</translation>
    </message>
    <message>
        <source>France</source>
        <translation>프랑스</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>독일</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>가나</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>그리스</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>홍콩</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>헝가리</translation>
    </message>
    <message>
        <source>India</source>
        <translation>인디아</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>인도네시아</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>아일랜드</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>이스라엘</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>이탈리아</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>일본</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>조단</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>케냐</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>말레이시아</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>멕시코</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>모로코</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>네델란드</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>뉴질랜드</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>나이제리아</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>페루</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>필리핀</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>폴란드</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>러시아</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>사우디 아라비아</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>싱가포르</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>사우스 아프리카</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>대한민국</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>스페인</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>스웨덴</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>대만</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>투니시아</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>터키</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>우간다</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>아랍에메레이트</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>영국</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>예멘</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>전세계</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>%1의 비디오 가져올수 없음</translation>
    </message>
</context>
</TS>